@@ -11,8 +11,7 @@ mix_and_clean_colors <- function(x)
   
   # skip horizons with a single color
   tab <- table(x$hz_id)
-  if(tab > 1)
-    {
+  if(tab > 1) {
     r <- with(x, wtd.mean(r, weights=pct))
     g <- with(x, wtd.mean(g, weights=pct))
     b <- with(x, wtd.mean(b, weights=pct))
@@ -56,20 +55,19 @@ get_site_data_from_pedon_db <- function(dsn)
 
   # exec query
   cat(paste('fetching from', dsn, '...\n'))
-  d <- sqlQuery(channel, q)
+  d <- sqlQuery(channel, q, stringsAsFactors=FALSE)
 
   # close connection
   odbcClose(channel)
   
-  # fix column types
-  d$site_id <- as.character(d$site_id)
-  d$pedon_id <- as.character(d$pedon_id)
-  d$datum <- as.character(d$datum)
-  
   # warn if mixed datums
   if(length(unique(na.omit(d$datum))) > 1)
     warning('multiple datums present')
   
+  # are there any dupes?
+  if(any(table(d$pedon_id) > 1))
+    warning('duplicate site/pedon information in results')
+  
   # done
   return(d)
   }
@@ -101,16 +99,11 @@ get_hz_data_from_pedon_db <- function(dsn)
 
   # exec query
   cat(paste('fetching from', dsn, '...\n'))
-  d <- sqlQuery(channel, q)
+  d <- sqlQuery(channel, q, stringsAsFactors=FALSE)
 
   # close connection
   odbcClose(channel)
   
-  # fix column types
-  d$pedon_id <- as.character(d$pedon_id)
-  d$hz_id <- as.character(d$hz_id)
-  d$hzname <- as.character(d$hzname)
-  
   # done
   return(d)
   }
@@ -136,16 +129,12 @@ ORDER BY pedon.upedonid, phiidref, colormoistst;"
 
   # exec query
   cat(paste('fetching from', dsn, '...\n'))
-  d <- sqlQuery(channel, q)
+  d <- sqlQuery(channel, q, stringsAsFactors=FALSE)
 
   # close connection
   odbcClose(channel)
   
-  # convert factor to character
-  d$pedon_id <- as.character(d$pedon_id)  
-  d$colorhue <- as.character(d$colorhue)
-
-  # convert Munsell to RGB---> note: this is slow
+  # convert Munsell to RGB
   cat('converting Munsell to RGB ...\n')
   d.rgb <- with(d, munsell2rgb(colorhue, colorvalue, colorchroma, return_triplets=TRUE))
 
@@ -172,17 +161,6 @@ ORDER BY pedon.upedonid, phiidref, colormoistst;"
   rm(d, d.rgb, dry.colors, moist.colors, dry.colors.final, moist.colors.final)
   gc()
   
-  
-  ## probably not a good idea
-  # fill missing color with white
-#   d.final$d_r[is.na(d.final$d_r)] <- NA
-#   d.final$d_g[is.na(d.final$d_g)] <- NA
-#   d.final$d_b[is.na(d.final$d_b)] <- NA
-#   
-#   d.final$m_r[is.na(d.final$m_r)] <- NA
-#   d.final$m_g[is.na(d.final$m_g)] <- NA
-#   d.final$m_b[is.na(d.final$m_b)] <- NA
-  
   # done
   return(d.final)
   }
@@ -202,7 +180,7 @@ get_veg_from_AK_Site <- function(dsn)
 
   # exec query
   cat(paste('fetching from', dsn, '...\n'))
-  d <- sqlQuery(channel, q)
+  d <- sqlQuery(channel, q, stringsAsFactors=FALSE)
 
   # close connection
   odbcClose(channel)
